==> tooltrims-1.2.0%2Bmc1.21.8-sources.jar: archives/tater/tooltrims/datagen/ItemTagGenerator.java <==
package archives.tater.tooltrims.datagen;

import archives.tater.tooltrims.ToolTrimsTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1802;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;

public class ItemTagGenerator extends FabricTagProvider.ItemTagProvider {

    public ItemTagGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> completableFuture) {
        super(output, completableFuture, null);
    }

    @Override
    protected void method_10514(class_7225.class_7874 arg) {
        valueLookupBuilder(ToolTrimsTags.TRIMMABLE_TOOLS).method_71558(
                class_1802.field_8091,
                class_1802.field_8876,
                class_1802.field_8647,
                class_1802.field_8406,
                class_1802.field_8167,
                class_1802.field_8528,
                class_1802.field_8776,
                class_1802.field_8387,
                class_1802.field_8062,
                class_1802.field_8431,
                class_1802.field_8845,
                class_1802.field_8322,
                class_1802.field_8335,
                class_1802.field_8825,
                class_1802.field_8303,
                class_1802.field_8371,
                class_1802.field_8699,
                class_1802.field_8403,
                class_1802.field_8475,
                class_1802.field_8609,
                class_1802.field_8802,
                class_1802.field_8250,
                class_1802.field_8377,
                class_1802.field_8556,
                class_1802.field_8527,
                class_1802.field_22022,
                class_1802.field_22023,
                class_1802.field_22024,
                class_1802.field_22025,
                class_1802.field_22026,
                class_1802.field_8102,
                class_1802.field_8399,
                class_1802.field_8547,
                class_1802.field_49814
        );
        valueLookupBuilder(ToolTrimsTags.TOOL_TRIM_MATERIALS).method_71558(
                class_1802.field_8620,
                class_1802.field_27022,
                class_1802.field_8695,
                class_1802.field_8759,
                class_1802.field_8687,
                class_1802.field_8477,
                class_1802.field_22020,
                class_1802.field_8725,
                class_1802.field_8155,
                class_1802.field_27063,
                class_1802.field_55044
        );
    }
}

==> tooltrims-1.3.0%2Bmc1.21.1-sources.jar: archives/tater/tooltrims/datagen/ItemTagGenerator.java <==
package archives.tater.tooltrims.datagen;

import archives.tater.tooltrims.ToolTrimsTags;
import net.fabricmc.fabric.api.datagen.v1.FabricDataOutput;
import net.fabricmc.fabric.api.datagen.v1.provider.FabricTagProvider;
import net.minecraft.class_1802;
import net.minecraft.class_7225;
import java.util.concurrent.CompletableFuture;

public class ItemTagGenerator extends FabricTagProvider.ItemTagProvider {

    public ItemTagGenerator(FabricDataOutput output, CompletableFuture<class_7225.class_7874> completableFuture) {
        super(output, completableFuture, null);
    }

    @Override
    protected void method_10514(class_7225.class_7874 arg) {
        method_10512(ToolTrimsTags.TRIMMABLE_TOOLS).add(
                class_1802.field_8091,
                class_1802.field_8876,
                class_1802.field_8647,
                class_1802.field_8406,
                class_1802.field_8167,
                class_1802.field_8528,
                class_1802.field_8776,
                class_1802.field_8387,
                class_1802.field_8062,
                class_1802.field_8431,
                class_1802.field_8845,
                class_1802.field_8322,
                class_1802.field_8335,
                class_1802.field_8825,
                class_1802.field_8303,
                class_1802.field_8371,
                class_1802.field_8699,
                class_1802.field_8403,
                class_1802.field_8475,
                class_1802.field_8609,
                class_1802.field_8802,
                class_1802.field_8250,
                class_1802.field_8377,
                class_1802.field_8556,
                class_1802.field_8527,
                class_1802.field_22022,
                class_1802.field_22023,
                class_1802.field_22024,
                class_1802.field_22025,
                class_1802.field_22026,
                class_1802.field_8102,
                class_1802.field_8399,
                class_1802.field_8547,
                class_1802.field_49814
        );
        method_10512(ToolTrimsTags.TOOL_TRIM_MATERIALS).add(
                class_1802.field_8620,
                class_1802.field_27022,
                class_1802.field_8695,
                class_1802.field_8759,
                class_1802.field_8687,
                class_1802.field_8477,
                class_1802.field_22020,
                class_1802.field_8725,
                class_1802.field_8155,
                class_1802.field_27063
        );
    }
}
